# ##### BEGIN GPL LICENSE BLOCK #####
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# ##### END GPL LICENSE BLOCK #####

bl_info = {
    "name": "Select Paint Target",
    "author": "Witold Jaworski",
    "version": (1, 1),
    "blender": (2, 7, 2),
    "location": "None (press right mouse button)",
    "description": "Selects new active object in the Texture Paint mode",
    "warning": "",
    "wiki_url": "",
    "tracker_url": "",
    "category": "Paint"}

_DEBUG = 0 #Set it to 1 or 2 to see some diagnostic messages on the Blender system console
import bpy
from bpy.types import Operator
from bpy.utils import register_module, unregister_module

class Select(Operator):
    bl_idname = "view3d.select_paint_target"
    bl_label = "Select Paint Target"
    bl_options = {'REGISTER','UNDO'}
    
    #--- Blender interface methods
    @classmethod
    def poll(cls,context):
        return (context.mode == 'PAINT_TEXTURE')
    
    def execute(self, context):
        #bpy.ops.paint.texture_paint_toggle()
        bpy.ops.view3d.select('INVOKE_DEFAULT')
        if context.mode == 'OBJECT':
            bpy.ops.paint.texture_paint_toggle()
        return{'FINISHED'}

    def invoke(self, context, event):
        return self.execute(context)


def register():
    register_module(__name__)
    km = bpy.context.window_manager.keyconfigs.addon
    if km:
        if 'Image Paint' in km.keymaps.keys():
            keymap = km.keymaps['Image Paint'].keymap_items
        else:
            keymap = km.keymaps.new(name='Image Paint', space_type='EMPTY').keymap_items
        keymap.new(Select.bl_idname, 'SELECTMOUSE', 'PRESS')
    if _DEBUG: print("select_paint_target - registered!")
    
def unregister():
    km = bpy.context.window_manager.keyconfigs.addon
    if km:
        if 'Image Paint' in km.keymaps.keys():
            keymap = km.keymaps['Image Paint'].keymap_items
            if Select.bl_idname in keymap.keys():
                item = keymap[Select.bl_idname]
                keymap.remove(item)
    unregister_module(__name__)
    if _DEBUG: print("select_paint_target - unregistered!")

if __name__ == "__main__":
    register()
